From b45fc6850c31ac8decf6421492fbe00f0cce4606 Mon Sep 17 00:00:00 2001
From: intrigeri <intrigeri@boum.org>
Date: Wed, 1 Jan 2020 12:25:07 +0000
Subject: [PATCH] Build system: retrieve artifacts directly from the build
 directory

As anonym wrote on #11171, "since we cannot mount 9p filesystems with write
easily (permissions-wise vs. the host, at least) our vagrant-libvirt setup has
to write the artifacs to disk (inside the guest) as an intermediate step".

This intermediate step takes time. It turns out we can skip this step, even
without a writable 9p shared folder, by retrieving the artifacts directly from
the build directory.
---
 Rakefile                             | 10 +++++++++-
 vagrant/provision/assets/build-tails |  2 --
 2 files changed, 9 insertions(+), 3 deletions(-)

diff --git a/Rakefile b/Rakefile
index 529197c110..eef423fe90 100644
--- a/Rakefile
+++ b/Rakefile
@@ -331,7 +331,15 @@ end
 
 def list_artifacts
   user = vagrant_ssh_config('User')
-  stdout = capture_vagrant_ssh("find '/home/#{user}/amnesia/' -maxdepth 1 " +
+  build_dirs = capture_vagrant_ssh(
+    "find /tmp -maxdepth 1 -type d -name 'tails-build.*' -printf '%p:%T@'")
+                .first.split("\n")
+  return Array.new if build_dirs.empty?
+  newest_build_dir = build_dirs
+                       .map  { |l| l.split(':') }
+                       .sort { |a, b| a[1].to_f <=> b[1].to_f }
+                       .last[0]
+  stdout = capture_vagrant_ssh("find '#{newest_build_dir}' -maxdepth 1 " +
                                         "-name 'tails-amd64-*' " +
                                         "-o -name tails-build-env.list").first
   stdout.split("\n")
diff --git a/vagrant/provision/assets/build-tails b/vagrant/provision/assets/build-tails
index 1762a7f28d..0f603447e2 100755
--- a/vagrant/provision/assets/build-tails
+++ b/vagrant/provision/assets/build-tails
@@ -170,5 +170,3 @@ as_root_do lb config --cache false
 as_root_do lb build
 
 shrink_acng_cache "${TAILS_PROXY_TYPE}"
-
-mv -f tails-* "${TAILS_GIT_DIR}/"
-- 
2.25.0.rc0

